# Introduction {#mainpage}

<!--
SPDX-FileCopyrightText: 2021-2024 The Ikarus Developers mueller@ibb.uni-stuttgart.de
SPDX-License-Identifier: LGPL-3.0-or-later

The content of the file is partly adapted from https://git.iws.uni-stuttgart.de/dumux-repositories/dumux/-/blob/master/README.md?ref_type=heads.
-->

<img align="left" src="BigLogo_transparent.png" width="800" alt="Ikarus logo">  

## Overview

This is the class documentation for the Ikarus module.
This project tries to provide an easy-to-read and an easy-to-use finite element framework.
It is heavily inspired by the finite element software DUNE, the book DUNE — The Distributed and Unified Numerics Environment, deal.II and Kratos.
Furthermore, it directly uses several modules from DUNE.

\section mods Modules
The best way to start is from the page \ref group_main "Modules" which gives
you access to the documentation by category.

For the license, see \ref LICENSE.md "License".

## How to cite

Ikarus is research software and developed at research institutions.
You can cite **specific releases** via [**DaRUS**](https://darus.uni-stuttgart.de/dataverse/ikarus).
You can also cite individual code files or even lines via **Software Heritage**: [![SWHRelease](https://archive.softwareheritage.org/badge/swh:1:rel:2cbfacc591c5fa48bdc84b375e42d1ab5304425f/)](https://archive.softwareheritage.org/swh:1:rel:2cbfacc591c5fa48bdc84b375e42d1ab5304425f;origin=https://github.com/ikarus-project/ikarus;visit=swh:1:snp:22424908ab42ab0d38be84c34235b8b5ae7af6c4)

If you are using Ikarus in scientific publications and in
the academic context, please cite publication:

**Ikarus v0.3.** [![Doi](https://img.shields.io/badge/DOI-10.18419%2Fdarus--3303-orange)](https://doi.org/10.18419/darus-3303)

```bib
@data{darus-3303_2023,
author = {Müller, Alexander and Vinod Kumar Mitruka, Tarun Kumar Mitruka},
publisher = {DaRUS},
title = {{Ikarus v0.3}},
year = {2023},
version = {V1},
doi = {10.18419/darus-3303},
url = {https://doi.org/10.18419/darus-3303}
}
```
